@@ -78,6 +78,7 @@ int test_sf_val (double val, double val_in, double tol, const char * desc);
 int test_sf_rlx (gsl_sf_result r, double val_in, double tol, int status, int expect_return, const char * desc);
 int test_sf_2 (gsl_sf_result r1, double val1, double tol1, gsl_sf_result r2, double val2, double tol2, int status, int expect_return, const char * desc);
 int test_sf_sgn (gsl_sf_result r, double sgn, double val_in, double tol, double expect_sgn, int status, int expect_return, const char * desc);
+int test_sf_return (int status, int expect_return, const char * desc);
 
 #define TEST_SF(stat, func, args, val_in, tol, expect_return) { int status = func args; stat += test_sf(r, val_in, tol, status, expect_return, #func #args); }
 
@@ -93,7 +94,10 @@ int test_sf_sgn (gsl_sf_result r, double sgn, double val_in, double tol, double
 
 #define TEST_SF_THETA(stat, func, args, val_in, tol) { int status; theta=args; status = func (&theta);  stat += test_sf_val(theta, val_in, tol, #func #args); }
 
+#define TEST_SF_RETURN(stat, func, args, expect_return) { int status = func args; stat += test_sf_return(status, expect_return, #func #args); }
+
 int test_airy(void);
+int test_alf(void);
 int test_bessel(void);
 int test_coulomb(void);
 int test_dilog(void);
